function C = JordanProduct(A,B)
%% Jordan product for symmetric matrices
%
% computes
%
% C = (A*B+B*A)/2
%
% which in contrast to the standard matrix product preserves symmetry.
%
% refs:
% A Directional Rouy-Tourin Scheme for Adaptive Matrix-Valued Morphology
% L. Pizarro, B. Burgeth, M. Breuß, J. Weickert, 2009
%
% Mandatory Parameters:
%
% A: 2 x 2 matrix
% B: 2 x 2 matrix
%
% Optional Parameters:
%
% -
%
% Output Parameters:
%
% C: 2 x 2 matrix

% Copyright (c) 2016 Laurent Hoeltgen <hoeltgen@b-tu.de>
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 3 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
% FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
% Street, Fifth Floor, Boston, MA 02110-1301, USA.

% Last revision: 2016-12-04 20:00

%% Parse input and output.

narginchk(2, 2);
nargoutchk(0, 1);

parser               = inputParser;
parser.FunctionName  = mfilename;
parser.KeepUnmatched = false;
parser.StructExpand  = false;

% Parse mandatory arguments

parser.addRequired('A', ...
    @(x) validateattributes(x, ...
    {'numeric'}, ...
    {'size', [2, 2], 'nonempty', 'nonsparse'}, ...
    mfilename, 'A', 1));

parser.addRequired('B', ...
    @(x) validateattributes(x, ...
    {'numeric'}, ...
    {'size', [2, 2], 'nonempty', 'nonsparse'}, ...
    mfilename, 'B', 2));

parser.parse(A,B);

%% Run Code

C = (A*B + B*A)/2;