function C = sgnMat(A)
%% Computes the sign of a matrix
%
% computes the sign according to the formula
%
% sgnMat(A) = V*diag(sgn(d_1), ..., sgn(d_n))*(V^T)
%
% refs:
% Morphology for Matrix Data: Ordering versus PDE-Based Approach
% B. Burgeth, A. Bruhn, S. Didas, J. Weickert, M. Welk, 2006
%
% A Directional Rouy-Tourin Scheme for Adaptive Matrix-Valued Morphology
% L. Pizarro, B. Burgeth, M. Breuß, J. Weickert, 2009
%
% Mandatory Parameters:
%
% A: 2 x 2 symmetric matrix
%
% Optional Parameters:
%
% -
%
% Output Parameters:
%
% C: 2 x 2 matrix
%
% Note: currently only works for symmetric matrices

% Copyright (c) 2016 Laurent Hoeltgen <hoeltgen@b-tu.de>
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 3 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
% FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
% Street, Fifth Floor, Boston, MA 02110-1301, USA.

% Last revision: 2016-12-02 11:00

%% Parse input and output.

narginchk(1, 1);
nargoutchk(0, 1);

parser               = inputParser;
parser.FunctionName  = mfilename;
parser.KeepUnmatched = false;
parser.StructExpand  = false;

% Parse mandatory arguments

parser.addRequired('A', ...
    @(x) validateattributes(x, ...
    {'numeric'}, ...
    {'size', [2, 2], 'nonempty', 'nonsparse'}, ...
    mfilename, 'A', 1));

parser.parse(A);

%tmp = abs(A-A')<1e-10;
%assert(all(tmp(:)), 'Input matrix is not symetric');

%% Run Code

[V, D] = eig(A);
if rcond(V) < 1e-10
    C = V*sign(D)*(V');
else
    C = (V*sign(D))/V;
end
end