function [ux, uy] = RTGrad(u, siz)
%% Compute matrix Gradient of 2x2 matrix valued image with Rouy-Tourin 
%
% Computes derivatives based on a finite difference scheme. Acts channel
% wise
%
% Mandatory Parameters:
%
% u:   input image (colour cone coded)
% siz: grid size (positive scalar)
%
% Optional Parameters:
%
% -
%
% Output Parameters:
%
% nabla : resulting gradient
%
% See also RTdiff, RTGradMag

% Copyright (c) 2016 Laurent Hoeltgen <hoeltgen@b-tu.de>
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 3 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
% FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
% Street, Fifth Floor, Boston, MA 02110-1301, USA.

% Last revision: 2016-12-02 10:00

import PDEMorphology.RTdiff

%% Parse input and output.

narginchk(2, 2);
nargoutchk(0, 2);

parser               = inputParser;
parser.FunctionName  = mfilename;
parser.KeepUnmatched = false;
parser.StructExpand  = false;

% Parse mandatory arguments

parser.addRequired('u', ...
    @(x) validateattributes(x, ...
    {'numeric'}, ...
    {'size', [NaN, NaN, 2, 2], 'nonempty', 'nonsparse'}, ...
    mfilename, 'u', 1));

parser.addRequired('siz', ...
    @(x) validateattributes(x, ...
    {'double'}, ...
    {'scalar', 'positive'}, ...
    mfilename, 'siz', 2));

parser.parse(u, siz);

%% Run Code

ux = RTdiff(u, siz, 'x'); % Compute x derivative
uy = RTdiff(u, siz, 'y'); % Compute y derivative

end
