function tests = mat2rgbtest()
%% Unit Tests for mat2rgb and rgb2mat
%
% Example
%
% results = runtests('mat2rgbtest.m')
%
% See also mat2rgb, rgb2mat

% Copyright (c) 2016 Laurent Hoeltgen <hoeltgen@b-tu.de>
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 3 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
% FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
% Street, Fifth Floor, Boston, MA 02110-1301, USA.

% Last revision: 2016-05-12 14:00

tests = functiontests(localfunctions);
end

function testmat1a(testCase)
import ColourCone.*

X = randi(255, 100, 1, 3);
verifyEqual(testCase, ...
    mat2rgb(rgb2mat(X)), X, 'AbsTol', 1e-12);
end

function testmat1b(testCase)
import ColourCone.*

X = randi(255, 1, 100, 3);
verifyEqual(testCase, ...
    mat2rgb(rgb2mat(X)), X, 'AbsTol', 1e-12);
end

function testmat1c(testCase)
import ColourCone.*

X = randi(255, 100, 100, 3);
verifyEqual(testCase, ...
    mat2rgb(rgb2mat(X)), X, 'AbsTol', 1e-12);
end

function testmat2a(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
X(1, 1, :) = [255, 255, 255];
Y = rgb2mat(X);
verifyEqual(testCase, ...
    reshape(Y(1, 1, :, :), 2, 2), ...
    sqrt(2)/2 * [1, 0; 0, 1], 'AbsTol', 1e-12);
end

function testmat2b(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
X(1, 1, :) = [0, 0, 0];
Y = rgb2mat(X);
verifyEqual(testCase, ...
    reshape(Y(1, 1, :, :), 2, 2), ...
    -sqrt(2)/2 * [1, 0; 0, 1], 'AbsTol', 1e-12);
end

function testmat2c(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
X(1, 1, :) = [255, 255, 255]/2;
Y = rgb2mat(X);
verifyEqual(testCase, ...
    reshape(Y(1, 1, :, :), 2, 2), ...
    [0, 0; 0, 0], 'AbsTol', 1e-12);
end

function testmat2d(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
X(1, 1, :) = [255, 0, 0];
Y = rgb2mat(X);
verifyEqual(testCase, ...
    reshape(Y(1, 1, :, :), 2, 2), ...
    sqrt(2)/2 * [0, 1; 1, 0], 'AbsTol', 1e-12);
end

function testmat2e(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
X(1, 1, :) = [0, 0, 255];
Y = rgb2mat(X);
verifyEqual(testCase, ...
    reshape(Y(1, 1, :, :), 2, 2), ...
    -1/4 * [-sqrt(6), sqrt(2); sqrt(2), sqrt(6)], 'AbsTol', 1e-12);
end

function testmat2f(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
X(1, 1, :) = [255, 0, 0]/2;
Y = rgb2mat(X);
verifyEqual(testCase, ...
    reshape(Y(1, 1, :, :), 2, 2), ...
    sqrt(2)/4 * [-1, 1; 1, -1], 'AbsTol', 1e-12);
end

function testmat2g(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
X(1, 1, :) = [0, 255, 255];
Y = rgb2mat(X);
verifyEqual(testCase, ...
    reshape(Y(1, 1, :, :), 2, 2), ...
    -sqrt(2)/2 * [0, 1; 1, 0], 'AbsTol', 1e-12);
end

function testmat2h(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
X(1, 1, :) = [0, 255, 0];
Y = rgb2mat(X);
verifyEqual(testCase, ...
    reshape(Y(1, 1, :, :), 2, 2), ...
    -1/4 * [sqrt(6), sqrt(2); sqrt(2), -sqrt(6)], 'AbsTol', 1e-12);
end

function testmat2i(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
X(1, 1, :) = [255, 0, 255];
Y = rgb2mat(X);
verifyEqual(testCase, ...
    reshape(Y(1, 1, :, :), 2, 2), ...
    1/4 * [sqrt(6), sqrt(2); sqrt(2), -sqrt(6)], 'AbsTol', 1e-12);
end

function testmat2j(testCase)
import ColourCone.*

X = zeros(4, 1, 3);
X(1, 1, :) = [191, 170, 181];
X(2, 1, :) = [  0,   0,   0];
X(3, 1, :) = [255, 255, 255];
X(4, 1, :) = [128, 153, 138];

Z = rgb2mat(X);
Y = mat2rgb(Z);
verifyEqual(testCase, Y, X, 'AbsTol', 1e-12);
end

function testmat2k(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
for kk = 1:1000
    X(1, 1, :) = randi(255, 1, 3);
    Y = mat2rgb(rgb2mat(X));
    verifyEqual(testCase, Y, X, 'AbsTol', 1e-12);
end
end

function testmat2l(testCase)
import ColourCone.*

X = zeros(1, 1, 3);
for kk = 1:255
    X(1, 1, :) = [kk, kk, kk];
    Y = mat2rgb(rgb2mat(X));
    verifyEqual(testCase, Y, X, 'AbsTol', 1e-12);
end
end